vector

package
v0.0.0-...-99b389f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2016 License: MIT Imports: 1 Imported by: 9

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type FnDim0

type FnDim0 func(Vector) (float64, error)

type FnDim0_1

type FnDim0_1 func(Vector) (float64, Vector, error)

type FnDim1

type FnDim1 func(Vector) (Vector, error)

type Vector

type Vector []float64

func ZeroVector

func ZeroVector(dimension int) Vector

Create a vector of given dimension with all components zeroed.

func (Vector) AbsMax

func (v Vector) AbsMax() float64

Return the maximum of the absolute values of the vector's components.

func (Vector) Add

func (v Vector) Add(u *Vector)

Set u = u + v

func (Vector) ContainsNaN

func (v Vector) ContainsNaN() bool

Return true iff one or more elements of v is NaN.

func (Vector) Equals

func (v Vector) Equals(u Vector) bool

Check if v is equal to u.

func (Vector) Mul

func (v Vector) Mul(x float64, u *Vector)

Set u = x * v

Jump to