Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Vector ¶
type Vector []float64
func ZeroVector ¶
Create a vector of given dimension with all components zeroed.
func (Vector) ContainsNaN ¶
Return true iff one or more elements of v is NaN.
Click to show internal directories.
Click to hide internal directories.